import { select } from 'd3';
import { viz } from './viz';
import { data } from '@Sreelikhith/heart_failure_prediction';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const groupData = data.reduce((acc, val) => {
    if (!acc[val.ChestPainType]) {
      acc[val.ChestPainType] = { M: 0, F: 0 };
    }
    acc[val.ChestPainType][val.Sex]++;
    return acc;
  }, {});

  const preparedData = Object.keys(groupData).map(
    (key) => ({
      ChestPainType: key,
      ...groupData[key],
    }),
  );

  viz(svg, {
    data: preparedData,
    xValue: (d) => d.ChestPainType,
    xAxisLabelText: 'Chest Pain Type',
    xAxisLabelOffset: 50,
    yAxisLabelText: 'Count',
    yAxisLabelOffset: -40,
    marginLeft: 60,
    marginTop: 20,
    marginRight: 20,
    marginBottom: 60,
    width,
    height,
    innerRectFill: '#f0f0f0',
  });
};
